==> admin-data-explorer-api_sjs1_3-0.5.10-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"admin-data-explorer-api","t":"admin-data-explorer-api","d":"","k":"static"},
{"l":"net/wiringbits/webapp/utils/api.html","n":"net.wiringbits.webapp.utils.api","t":"package net.wiringbits.webapp.utils.api","d":"net/wiringbits/webapp/utils/api","k":"package"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"AdminDataExplorerApiClient","t":"trait AdminDataExplorerApiClient","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"trait"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"createItem","t":"def createItem(tableName: String, request: Request): Future[Response]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"deleteItem","t":"def deleteItem(tableName: String, id: String): Future[Response]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"getTableMetadata","t":"def getTableMetadata(tableName: String, sort: List[String], range: List[Int], filter: String): Future[List[Map[String, String]]]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"getTables","t":"def getTables: Future[Response]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"updateItem","t":"def updateItem(tableName: String, id: String, request: Map[String, String]): Future[Response]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"viewItem","t":"def viewItem(tableName: String, id: String): Future[Map[String, String]]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"viewItems","t":"def viewItems(tableName: String, ids: List[String]): Future[List[Map[String, String]]]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient$.html","n":"AdminDataExplorerApiClient","t":"object AdminDataExplorerApiClient","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient$$Config.html","n":"Config","t":"class Config(serverUrl: String)","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient$$Config","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient$$DefaultImpl.html","n":"DefaultImpl","t":"class DefaultImpl(config: Config)(implicit backend: SttpBackend[Future, _], ec: ExecutionContext) extends AdminDataExplorerApiClient","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient$$DefaultImpl","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models.html","n":"net.wiringbits.webapp.utils.api.models","t":"package net.wiringbits.webapp.utils.api.models","d":"net/wiringbits/webapp/utils/api/models","k":"package"},
{"l":"net/wiringbits/webapp/utils/api/models.html","n":"errorResponseFormat","t":"val errorResponseFormat: Format[ErrorResponse]","d":"net/wiringbits/webapp/utils/api/models","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models.html","n":"instantFormat","t":"val instantFormat: Format[Instant]","d":"net/wiringbits/webapp/utils/api/models","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$.html","n":"AdminCreateTable","t":"object AdminCreateTable","d":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$.html","n":"adminCreateTableRequestFormat","t":"val adminCreateTableRequestFormat: Format[Request]","d":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$.html","n":"adminCreateTableResponseFormat","t":"val adminCreateTableResponseFormat: Format[Response]","d":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$$Request.html","n":"Request","t":"class Request(data: Map[String, String])","d":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$$Request","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$$Response.html","n":"Response","t":"class Response(noData: String)","d":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$$Response","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminDeleteTable$.html","n":"AdminDeleteTable","t":"object AdminDeleteTable","d":"net/wiringbits/webapp/utils/api/models/AdminDeleteTable$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminDeleteTable$.html","n":"adminDeleteTableResponseFormat","t":"val adminDeleteTableResponseFormat: Format[Response]","d":"net/wiringbits/webapp/utils/api/models/AdminDeleteTable$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminDeleteTable$$Response.html","n":"Response","t":"class Response(noData: String)","d":"net/wiringbits/webapp/utils/api/models/AdminDeleteTable$$Response","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$.html","n":"AdminGetTables","t":"object AdminGetTables","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$.html","n":"adminGetTablesResponseFormat","t":"val adminGetTablesResponseFormat: Format[Response]","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response.html","n":"Response","t":"class Response(data: List[DatabaseTable])","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$.html","n":"Response","t":"object Response","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$.html","n":"adminDatabaseTableResponseFormat","t":"val adminDatabaseTableResponseFormat: Format[DatabaseTable]","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$.html","n":"adminTableColumnResponseFormat","t":"val adminTableColumnResponseFormat: Format[TableColumn]","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$.html","n":"adminTableReferenceResponseFormat","t":"val adminTableReferenceResponseFormat: Format[TableReference]","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$$DatabaseTable.html","n":"DatabaseTable","t":"class DatabaseTable(name: String, columns: List[TableColumn], primaryKeyName: String, canBeDeleted: Boolean)","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$$DatabaseTable","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$$TableColumn.html","n":"TableColumn","t":"class TableColumn(name: String, `type`: String, editable: Boolean, reference: Option[TableReference])","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$$TableColumn","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$$TableReference.html","n":"TableReference","t":"class TableReference(referencedTable: String, referenceField: String)","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$$TableReference","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$.html","n":"AdminUpdateTable","t":"object AdminUpdateTable","d":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$.html","n":"adminUpdateTableRequestFormat","t":"val adminUpdateTableRequestFormat: Format[Request]","d":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$.html","n":"adminUpdateTableResponseFormat","t":"val adminUpdateTableResponseFormat: Format[Response]","d":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$$Request.html","n":"Request","t":"class Request(data: Map[String, String])","d":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$$Request","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$$Response.html","n":"Response","t":"class Response(id: String)","d":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$$Response","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/ErrorResponse.html","n":"ErrorResponse","t":"class ErrorResponse(error: String)","d":"net/wiringbits/webapp/utils/api/models/ErrorResponse","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse.html","n":"PlayErrorResponse","t":"class PlayErrorResponse(error: PlayError)","d":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$.html","n":"PlayErrorResponse","t":"object PlayErrorResponse","d":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$.html","n":"playErrorResponseErrorFormat","t":"val playErrorResponseErrorFormat: Format[PlayError]","d":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$.html","n":"playErrorResponseFormat","t":"val playErrorResponseFormat: Format[PlayErrorResponse]","d":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$$PlayError.html","n":"PlayError","t":"class PlayError(message: String)","d":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$$PlayError","k":"class"},
{"l":"docs/index.html","n":"admin-data-explorer-api","t":"admin-data-explorer-api","d":"","k":"static"}];

==> admin-data-explorer-api_sjs1_3-0.5.16-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"admin-data-explorer-api","t":"admin-data-explorer-api","d":"","k":"static"},
{"l":"net/wiringbits/webapp/utils/api.html","n":"net.wiringbits.webapp.utils.api","t":"package net.wiringbits.webapp.utils.api","d":"net/wiringbits/webapp/utils/api","k":"package"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"AdminDataExplorerApiClient","t":"trait AdminDataExplorerApiClient","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"trait"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"createItem","t":"def createItem(tableName: String, request: Request): Future[Response]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"deleteItem","t":"def deleteItem(tableName: String, id: String): Future[Response]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"getTableMetadata","t":"def getTableMetadata(tableName: String, sort: List[String], range: List[Int], filter: String): Future[List[Map[String, String]]]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"getTables","t":"def getTables: Future[Response]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"updateItem","t":"def updateItem(tableName: String, id: String, request: Map[String, String]): Future[Response]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"viewItem","t":"def viewItem(tableName: String, id: String): Future[Map[String, String]]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient.html","n":"viewItems","t":"def viewItems(tableName: String, ids: List[String]): Future[List[Map[String, String]]]","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient","k":"def"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient$.html","n":"AdminDataExplorerApiClient","t":"object AdminDataExplorerApiClient","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient$$Config.html","n":"Config","t":"class Config(serverUrl: String)","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient$$Config","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient$$DefaultImpl.html","n":"DefaultImpl","t":"class DefaultImpl(config: Config)(implicit backend: SttpBackend[Future, _], ec: ExecutionContext) extends AdminDataExplorerApiClient","d":"net/wiringbits/webapp/utils/api/AdminDataExplorerApiClient$$DefaultImpl","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models.html","n":"net.wiringbits.webapp.utils.api.models","t":"package net.wiringbits.webapp.utils.api.models","d":"net/wiringbits/webapp/utils/api/models","k":"package"},
{"l":"net/wiringbits/webapp/utils/api/models.html","n":"errorResponseFormat","t":"val errorResponseFormat: Format[ErrorResponse]","d":"net/wiringbits/webapp/utils/api/models","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models.html","n":"instantFormat","t":"val instantFormat: Format[Instant]","d":"net/wiringbits/webapp/utils/api/models","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$.html","n":"AdminCreateTable","t":"object AdminCreateTable","d":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$.html","n":"adminCreateTableRequestFormat","t":"val adminCreateTableRequestFormat: Format[Request]","d":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$.html","n":"adminCreateTableResponseFormat","t":"val adminCreateTableResponseFormat: Format[Response]","d":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$$Request.html","n":"Request","t":"class Request(data: Map[String, String])","d":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$$Request","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$$Response.html","n":"Response","t":"class Response(noData: String)","d":"net/wiringbits/webapp/utils/api/models/AdminCreateTable$$Response","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminDeleteTable$.html","n":"AdminDeleteTable","t":"object AdminDeleteTable","d":"net/wiringbits/webapp/utils/api/models/AdminDeleteTable$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminDeleteTable$.html","n":"adminDeleteTableResponseFormat","t":"val adminDeleteTableResponseFormat: Format[Response]","d":"net/wiringbits/webapp/utils/api/models/AdminDeleteTable$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminDeleteTable$$Response.html","n":"Response","t":"class Response(noData: String)","d":"net/wiringbits/webapp/utils/api/models/AdminDeleteTable$$Response","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$.html","n":"AdminGetTables","t":"object AdminGetTables","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$.html","n":"adminGetTablesResponseFormat","t":"val adminGetTablesResponseFormat: Format[Response]","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response.html","n":"Response","t":"class Response(data: List[DatabaseTable])","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$.html","n":"Response","t":"object Response","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$.html","n":"adminDatabaseTableResponseFormat","t":"val adminDatabaseTableResponseFormat: Format[DatabaseTable]","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$.html","n":"adminTableColumnResponseFormat","t":"val adminTableColumnResponseFormat: Format[TableColumn]","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$.html","n":"adminTableReferenceResponseFormat","t":"val adminTableReferenceResponseFormat: Format[TableReference]","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$$DatabaseTable.html","n":"DatabaseTable","t":"class DatabaseTable(name: String, columns: List[TableColumn], primaryKeyName: String, canBeDeleted: Boolean)","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$$DatabaseTable","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$$TableColumn.html","n":"TableColumn","t":"class TableColumn(name: String, `type`: String, editable: Boolean, reference: Option[TableReference], filterable: Boolean)","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$$TableColumn","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$$TableReference.html","n":"TableReference","t":"class TableReference(referencedTable: String, referenceField: String)","d":"net/wiringbits/webapp/utils/api/models/AdminGetTables$$Response$$TableReference","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$.html","n":"AdminUpdateTable","t":"object AdminUpdateTable","d":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$.html","n":"adminUpdateTableRequestFormat","t":"val adminUpdateTableRequestFormat: Format[Request]","d":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$.html","n":"adminUpdateTableResponseFormat","t":"val adminUpdateTableResponseFormat: Format[Response]","d":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$$Request.html","n":"Request","t":"class Request(data: Map[String, String])","d":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$$Request","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$$Response.html","n":"Response","t":"class Response(id: String)","d":"net/wiringbits/webapp/utils/api/models/AdminUpdateTable$$Response","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/ErrorResponse.html","n":"ErrorResponse","t":"class ErrorResponse(error: String)","d":"net/wiringbits/webapp/utils/api/models/ErrorResponse","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse.html","n":"PlayErrorResponse","t":"class PlayErrorResponse(error: PlayError)","d":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse","k":"class"},
{"l":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$.html","n":"PlayErrorResponse","t":"object PlayErrorResponse","d":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$","k":"object"},
{"l":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$.html","n":"playErrorResponseErrorFormat","t":"val playErrorResponseErrorFormat: Format[PlayError]","d":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$.html","n":"playErrorResponseFormat","t":"val playErrorResponseFormat: Format[PlayErrorResponse]","d":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$","k":"val"},
{"l":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$$PlayError.html","n":"PlayError","t":"class PlayError(message: String)","d":"net/wiringbits/webapp/utils/api/models/PlayErrorResponse$$PlayError","k":"class"},
{"l":"docs/index.html","n":"admin-data-explorer-api","t":"admin-data-explorer-api","d":"","k":"static"}];
